==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/KryteriumOpcja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class KryteriumOpcja extends GenericDPSObject {
    /**
     * KRYTERIUM_OPCJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * KRYTERIUM_OPCJA.KRYTERIUM_OCENY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kryteriumOcenyId;

    /**
     * KRYTERIUM_OPCJA.PUNKTY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer punkty;

    /**
     * KRYTERIUM_OPCJA.TEKST
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String tekst;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KRYTERIUM_OPCJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KRYTERIUM_OPCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KRYTERIUM_OPCJA.KRYTERIUM_OCENY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKryteriumOcenyId() {
        return kryteriumOcenyId;
    }

    /**
     * KRYTERIUM_OPCJA.KRYTERIUM_OCENY_ID
     *
     * @param kryteriumOcenyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKryteriumOcenyId(Long kryteriumOcenyId) {
        this.kryteriumOcenyId = kryteriumOcenyId;
    }

    /**
     * @return KRYTERIUM_OPCJA.PUNKTY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getPunkty() {
        return punkty;
    }

    /**
     * KRYTERIUM_OPCJA.PUNKTY
     *
     * @param punkty
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPunkty(Integer punkty) {
        this.punkty = punkty;
    }

    /**
     * @return KRYTERIUM_OPCJA.TEKST
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTekst() {
        return tekst;
    }

    /**
     * KRYTERIUM_OPCJA.TEKST
     *
     * @param tekst
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTekst(String tekst) {
        this.tekst = tekst == null ? null : tekst.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KryteriumOpcja other = (KryteriumOpcja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getKryteriumOcenyId() == null ? other.getKryteriumOcenyId() == null : this.getKryteriumOcenyId().equals(other.getKryteriumOcenyId()))
            && (this.getPunkty() == null ? other.getPunkty() == null : this.getPunkty().equals(other.getPunkty()))
            && (this.getTekst() == null ? other.getTekst() == null : this.getTekst().equals(other.getTekst()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getKryteriumOcenyId() == null) ? 0 : getKryteriumOcenyId().hashCode());
        result = prime * result + ((getPunkty() == null) ? 0 : getPunkty().hashCode());
        result = prime * result + ((getTekst() == null) ? 0 : getTekst().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", kryteriumOcenyId=").append(kryteriumOcenyId);
        sb.append(", punkty=").append(punkty);
        sb.append(", tekst=").append(tekst);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/KryteriumOpcja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class KryteriumOpcja extends GenericDPSObject {
    /**
     * KRYTERIUM_OPCJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * KRYTERIUM_OPCJA.KRYTERIUM_OCENY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kryteriumOcenyId;

    /**
     * KRYTERIUM_OPCJA.PUNKTY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer punkty;

    /**
     * KRYTERIUM_OPCJA.TEKST
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String tekst;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KRYTERIUM_OPCJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KRYTERIUM_OPCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KRYTERIUM_OPCJA.KRYTERIUM_OCENY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKryteriumOcenyId() {
        return kryteriumOcenyId;
    }

    /**
     * KRYTERIUM_OPCJA.KRYTERIUM_OCENY_ID
     *
     * @param kryteriumOcenyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKryteriumOcenyId(Long kryteriumOcenyId) {
        this.kryteriumOcenyId = kryteriumOcenyId;
    }

    /**
     * @return KRYTERIUM_OPCJA.PUNKTY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getPunkty() {
        return punkty;
    }

    /**
     * KRYTERIUM_OPCJA.PUNKTY
     *
     * @param punkty
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPunkty(Integer punkty) {
        this.punkty = punkty;
    }

    /**
     * @return KRYTERIUM_OPCJA.TEKST
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTekst() {
        return tekst;
    }

    /**
     * KRYTERIUM_OPCJA.TEKST
     *
     * @param tekst
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTekst(String tekst) {
        this.tekst = tekst == null ? null : tekst.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KryteriumOpcja other = (KryteriumOpcja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getKryteriumOcenyId() == null ? other.getKryteriumOcenyId() == null : this.getKryteriumOcenyId().equals(other.getKryteriumOcenyId()))
            && (this.getPunkty() == null ? other.getPunkty() == null : this.getPunkty().equals(other.getPunkty()))
            && (this.getTekst() == null ? other.getTekst() == null : this.getTekst().equals(other.getTekst()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getKryteriumOcenyId() == null) ? 0 : getKryteriumOcenyId().hashCode());
        result = prime * result + ((getPunkty() == null) ? 0 : getPunkty().hashCode());
        result = prime * result + ((getTekst() == null) ? 0 : getTekst().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", kryteriumOcenyId=").append(kryteriumOcenyId);
        sb.append(", punkty=").append(punkty);
        sb.append(", tekst=").append(tekst);
        sb.append("]");
        return sb.toString();
    }
}
